#========================================================================================
# package      DE_EPAGES::SageRestConnector::API::TLE::SageRestConnectorTLEHandler
# state        public
#----------------------------------------------------------------------------------------
# description  Implements TLE function
#----------------------------------------------------------------------------------------
# example
#========================================================================================
package DE_EPAGES::SageRestConnector::API::TLE::SageRestConnectorTLEHandler;
use DE_EPAGES::Core::API::Log qw( GetLog );
use DE_EPAGES::AppStore::API::Constants qw( APPSTORE_APP_TYPES );
use DE_EPAGES::SageRestConnector::API::Constants qw ( SageOmniSellerAppID );


use strict;

use strict;


#==================================================================================
# function     RegisterHandlerProc
# state        private
#----------------------------------------------------------------------------------
# syntax       $RegisterHandlerProc( $hParams );
#----------------------------------------------------------------------------------
# description  Function registers the TLE handler process.
#----------------------------------------------------------------------------------
# input        $hParams | hook arguments keys: Processor | hash reference
#==================================================================================
sub RegisterHandlerProc {
    my ($Params) = @_;

    __PACKAGE__->new()->register($Params->{'Processor'});
    return;
}

#========================================================================================
# function     new
# state        private
#----------------------------------------------------------------------------------------
# syntax       $Handler = new DE_EPAGES::SageRestConnector::API::TLE::SageRestConnectorTLEHandler;
# example      my $Handler  = new DE_EPAGES::SageRestConnector::API::TLE::SageRestConnectorTLEHandler;
#----------------------------------------------------------------------------------------
# description  create a new handler
#----------------------------------------------------------------------------------------
# return       $Handler | blessed object | object
#========================================================================================
sub new { bless {}, shift; }

#==================================================================================
# function     register
# state        private
#----------------------------------------------------------------------------------
# syntax       $Handler->register( $Processor );
#----------------------------------------------------------------------------------
# description  Function registers this handle on the processor.
#----------------------------------------------------------------------------------
# input        $Processor | tle processor | object
#==================================================================================
sub register {
    my $self = shift;
    my ($Processor) = @_;
    GetLog->debug( 'SageRestConnectorTLEHandler.RegisterHandlerProc' );

    $Processor->registerHandler( 'FunctionHandler', $self, 'OmniSellerAppAvailable' );

    return;
}

#========================================================================================
# function     OmniSellerAppAvailable
# state        public
#----------------------------------------------------------------------------------------
# syntax       #MollieAdded
#----------------------------------------------------------------------------------------
# description  Checks if the Sage  Omni Seller App can be installed to the shop.
#----------------------------------------------------------------------------------------
# input        #Processor | tle processor | object
# input        $aParams | #Shop.Object | array
# return       #Result | true if OmniSellerApp can be installed else false | boolean
#========================================================================================
sub OmniSellerAppAvailable {
    my $self = shift;
    my ($Processor, $aParams) = @_;
    my ($Shop) = @$aParams;

    my $AppsClient = DE_EPAGES::AppStore::API::Object::AppsClient->create(
        {
            'Shop'   => $Shop,
            'Locale' => $Processor->tle('Locale')
        }
    );

    my $hParams = {};
    $hParams->{'resultsPerPage'} = 1000;

    my $Apps = $AppsClient->listApps( 1, APPSTORE_APP_TYPES, undef, undef, $hParams);

    my $appAvailable = 0;
    foreach my $hApp (@{$Apps->{'content'}}){
        #AppId for OmniSellerCartridge: 125A5DFC-3D8A-411D-B383-E77E38DB04E6
        if ($hApp->{'id'} eq SageOmniSellerAppID){
            $appAvailable = 1;
            last;
        }
    }

    return $appAvailable;

}
1;