#========================================================================================
# package      DE_EPAGES::Shop::API::Resource::PublicInfoResource
# state        public
# base         DE_EPAGES::Shop::API::Resource::BaseShopResource
# description  implements the REST resource for supported basic public content of a shop
#========================================================================================
package DE_EPAGES::Shop::API::Resource::PublicInfoResource;
use base DE_EPAGES::Shop::API::Resource::BaseShopResource;

use strict;
use feature 'switch';
use DE_EPAGES::Core::API::Url qw ( ParseQueryString );
use DE_EPAGES::Object::API::Factory qw ( LoadObjectByPath );
use DE_EPAGES::Object::API::Object::Locale;
use DE_EPAGES::Object::API::Language qw ( GetPKeyLanguageByCode );
use DE_EPAGES::Shop::API::Resource::ShopRequestContext;
use DE_EPAGES::Shop::API::Url qw ( BuildShopUrl );

sub service {
    return LoadObjectByPath('/RestServices/PublicInfo');
}

sub match {
    my $self = shift;
    my ($Request) = @_;

    return unless $Request->uri->path =~ m|^/api/public-info/?$|;
    return 1;
}

sub producedContentTypes {
    my $self = shift;
    my ($RequestMethod) = @_;

    return {
        GET => [
            ['get', 'application/vnd.epages.v1+json'],
            ['get', 'application/json'],
        ],
        POST => [
            ['post', 'application/json'],
            ['post', 'application/vnd.epages.v1+json'],
        ],
    }->{$RequestMethod};
}

sub params {
    my $self = shift;
    my ($ActionName, $Object, $Request) = @_;

    given( $ActionName ) {
        when( 'get' ) {
            my $hQuery = ParseQueryString( $Request->uri->query, 'utf-8' );
            my $LocaleID = $hQuery->{'locale'}->[0];
            return [ $Object, $LocaleID ];
        }
        when( 'post' ) {
            return [ $Object];
        }
    }
}

sub get {
    my $self = shift;
    my ($Shop, $LocaleID) = @_;

    my $Context = DE_EPAGES::Shop::API::Resource::ShopRequestContext->new($Shop);
    $LocaleID = $Context->validLocale($LocaleID);
    my $LanguageID = DE_EPAGES::Object::API::Object::Locale->load($LocaleID)->get('LanguageID');

    # build shop logo url
    my $ShopLogoURL;
    if ($Shop->get('UseUnityShopLogo')) {
        $ShopLogoURL = $Context->imageBaseUrl() . $Shop->get('Logo');
    } else {
        $ShopLogoURL = defined $Shop->get('Logo') ? $Context->imageBaseUrl() . $Shop->get('WebPath') . '/'. $Shop->get('Logo') : undef;
    }

    my $ShopAddress = defined $Shop->get('Address') ? $Shop->get('Address') : undef;
    my $hAddressCountry = defined $Shop->get('Address') ? $Shop->get('Address')->get('Country') : undef;

    return {
        'name' => $Shop->get('NameOrAlias', $LanguageID),
        'email' => defined $ShopAddress ? $ShopAddress->get('EMail') : undef,
        'isInEU' => defined $ShopAddress ? $ShopAddress->get('IsEU') : undef,
        'countryCode2' => defined $hAddressCountry ? $hAddressCountry->{'Code2'} : undef,
        'slogan' => $Shop->get('Slogan', $LanguageID),
        'logoUrl' => $ShopLogoURL,
        'mboUrl' => _buildMBOUrl($Shop),
        'sfUrl' => _buildSfUrl($Shop),
    };
}

sub _buildMBOUrl{
        my ($Shop) = @_;
        return BuildShopUrl(
        $Shop,
        {
        },
        {
            'Type'   => 'admin',
            'UseSSL' => 1, 
            'UseObjectPath' => '1'
        }
    );
}

sub _buildSfUrl{
    my ($Shop) = @_;
    return BuildShopUrl( $Shop , {} , {'Type'   => 'sf', 'UseObjectPath' => '1'});
}

sub post {

    my $self = shift;
    my ($Shop, $Request) = @_;

    my $aNames = $Request->{names};
    my $aSlogans = $Request->{slogans};


    if( $Request->{names} ) {
     foreach my $hName ( @$aNames ){
       
        my $lang = (keys % $hName)[0];
        my $name = $hName->{$lang};
        my $langkey = GetPKeyLanguageByCode($lang);
       
        $Shop->set({Name => $name},$langkey);
       
    };
  }

    if( $Request->{slogans} ) {
     foreach my $hSlogan ( @$aSlogans ){
       
       my $lang = (keys % $hSlogan)[0];
       my $sloganname = $hSlogan->{$lang};
       my $langkey = GetPKeyLanguageByCode($lang);
       
       $Shop->set({Slogan => $sloganname}, $langkey)
              
    };
  }
  
# No action taken for the logo, since we do not receive required binary data in this call!


    return;
}

1;
